@@ -1,5 +1,5 @@
 import unittest
-from seamless.renderer import render
+from seamless import render
 from .components import App, Page
 
 
@@ -11,7 +11,8 @@ class NestedComponentsTest(unittest.TestCase):
         )
 
     def test_page_inheritance(self):
+        self.maxDiff = None
         self.assertEqual(
             render(Page(App())),
-            '<!DOCTYPE html><html><head lang="en"><meta charset="UTF-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><title></title><link rel="stylesheet" href="/static/style.css"></head><body dir="ltr"><div class="card"><h3 class="card-title">Card title</h3><hr><div>Card content</div></div></body></html>',
+            '<!DOCTYPE html><html lang="en"><head><meta charset="UTF-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><title></title><link rel="stylesheet" href="/static/style.css"></head><body dir="ltr"><div class="card"><h3 class="card-title">Card title</h3><hr><div>Card content</div></div></body></html>',
         )
